@@ -307,7 +307,7 @@ def generateMatchHistoryLegend(figAx):
 def plotTreemapByStages(
         figAx, stagesDF, 
         metric='win ratio', fmt='{:.2f}', title=True,
-        pad=0, lw=2, ec='#00000055', alpha=.5
+        pad=0.1, lw=2, ec='#00000055', alpha=.5
     ):
     """_summary_
 
@@ -336,7 +336,7 @@ def plotTreemapByStages(
 def plotTreemapByKey(
         figAx, keyedDF, key,
         metric='win ratio', fmt='{:.2f}', title=True,
-        pad=0, lw=2, ec='#00000055', alpha=.5,
+        pad=0.1, lw=2, ec='#00000055', alpha=.5,
         colors=cst.CLR_CLS_LONG
     ):
     """_summary_
@@ -384,4 +384,160 @@ def plotTreemapByKey(
         plt.title(metric)
     ax.set_aspect(1/ax.get_data_ratio())
     plt.axis('off')
+    return (fig, ax)
+
+
+def plotIris(
+        figAx, 
+        topArray, bottomArray=None, barArray=None, 
+        tbRange=(0, 50), bRange=(0, 2000),
+        rScale='symlog', innerOffset=0.75, clockwise=True,
+        colorsTop=(cst.CLR_STATS['kill'], cst.CLR_STATS['death']),
+        colorBars=cst.CLR_PAINT,
+        innerText=None, fontSize=20, fontColor='#00000066',
+        innerGuides=(0, 6, 1), innerGuidesColor="#00000066",
+        outerGuides=(0, 50, 5), outerGuidesColor="#00000088",
+        frameColor="#00000011"
+    ):
+    """Creates a barchart-style plot in a radial axis. The lines go from bottomArray to topArray, while the barArray is plotted as is from the origin.
+
+    Args:
+        figAx (tuple): (fig, ax) tuple as initialized by matplotlib (plt.subplots).
+        topArray (array):
+        bottomArray (array, optional):
+        barArray (array, optional):
+        tbRange (tuple, optional): y-range for the top-bottom radii. Defaults to (0, 50).
+        bRange (tuple, optional): y-range for the bar statistic. Defaults to (0, 2000).
+        rScale (str, optional): Way the circular axis will be scaled. Defaults to 'symlog'.
+        innerOffset (float, optional): Radius of the innermost circle to create a clear area at the centar of the plot. Defaults to 0.75.
+        clockwise (bool, optional): Sorting of the battles starts at 12 o'clock and goes clockwise. Defaults to True.
+        colorsTop (tuple, optional): Color of the line if kills are larger than deaths, and if they are not. Defaults to (cst.CLR_STATS['kill'], cst.CLR_STATS['death']).
+        colorBars (color, optional): Color of the bars assigned to the paint statistic. Defaults to cst.CLR_PAINT.
+        innerText (bool, optional): Add the inner label as the ratio of kills or kassists to deaths. Defaults to True.
+        innerTextFmt (str, optional): Formatting string for the inner label. Defaults to '{:.2f}'.
+        fontSize (int, optional): Font size for the inner label. Defaults to 20.
+        fontColor (str, optional): Font color for the inner label. Defaults to '#00000066'.
+        innerGuides (tuple, optional): Start, stop, increment values for the innermost guides on the radial axis. Defaults to (0, 6, 1).
+        innerGuidesColor (str, optional): Color for the innermost guides. Defaults to "#00000066".
+        outerGuides (tuple, optional): Start stop, increment values for the outermost guides on the radial axis. Defaults to (0, 50, 10).
+        outerGuidesColor (str, optional): Color for the outer guides. Defaults to "#00000088".
+        frameColor (str, optional): Color for the outermost radial frame. Defaults to "#00000011".
+
+    Returns:
+        (fix, ax): Matplotlib's fig and ax objects.
+    """    
+    (fig, ax) = figAx
+    ax.set_theta_offset(np.pi/2)
+    ax.set_rscale(rScale)
+    # Calculate angles for marker lines ---------------------------------------
+    DLEN = topArray.shape[0]
+    (astart, aend) = ((2*np.pi, 0) if clockwise else (0, 2*np.pi))
+    ANGLES = np.linspace(astart, aend, DLEN, endpoint=False)
+    # Draw top-bottom ---------------------------------------------------------
+    if bottomArray is None:
+        bottomArray = np.zeros(topArray.shape)
+    heights = topArray-bottomArray
+    colors = [colorsTop[0] if (h>=0) else colorsTop[1] for h in heights]
+    ax.vlines(
+        ANGLES, innerOffset+bottomArray, innerOffset+topArray, 
+        lw=0.5, colors=colors, alpha=.7
+    )
+    # Draw bar ----------------------------------------------------------------
+    if barArray is None:
+        barScaled = np.zeros(topArray.shape)
+    else:
+        barScaled = np.interp(barArray, bRange, tbRange)
+    ax.vlines(
+        ANGLES, innerOffset, innerOffset+barScaled,  
+        lw=1, colors=colorBars, alpha=.1
+    )
+    # Add inner text ----------------------------------------------------------
+    if innerText:
+        ax.text(
+            x=0.5, y=0.5, 
+            s=innerText, fontsize=fontSize,
+            va="center", ha="center",  ma="center", 
+            color=fontColor, transform=ax.transAxes
+        )
+    # Cleaning up axes --------------------------------------------------------
+    circleAngles = np.linspace(0, 2*np.pi, 200)
+    for r in range(*innerGuides):
+        ax.plot(
+            circleAngles, np.repeat(r+innerOffset, 200), 
+            color=innerGuidesColor, lw=0.1, ls='-.', zorder=-10
+        )
+    ax.set_xticks([])
+    ax.set_ylim(tbRange[0], tbRange[1]+innerOffset)
+    ax.set_yticklabels([])
+    yTicks = [0+innerOffset] + list(np.arange(
+        outerGuides[0]+innerOffset, outerGuides[1]+innerOffset, outerGuides[2]
+    ))
+    ax.set_yticks(yTicks)
+    ax.yaxis.grid(True, color=frameColor, ls='-', lw=0.125, zorder=-10)
+    ax.spines["start"].set_color("none")
+    ax.spines["polar"].set_color(outerGuidesColor)
+    # Return figure -----------------------------------------------------------
+    return (fig, ax)
+
+
+def plotkillDeathIris(
+        figAx, playerHistory, kassist=True, paint=True,
+        kRange=(0, 50), pRange=(0, 2000),
+        rScale='symlog', innerOffset=0.75, clockwise=True,
+        colorsTop=(cst.CLR_STATS['kill'], cst.CLR_STATS['death']),
+        colorBars=cst.CLR_PAINT,
+        innerText=True, innerTextFmt='{:.2f}',
+        fontSize=20, fontColor='#00000066',
+        innerGuides=(0, 6, 1), innerGuidesColor="#00000066",
+        outerGuides=(0, 50, 10), outerGuidesColor="#00000088",
+        frameColor="#00000011"
+    ):
+    """These plots show the kill to death ratios as bars arranged in a circular pattern.
+
+    Args:
+        figAx (tuple): (fig, ax) tuple as initialized by matplotlib (plt.subplots).
+        playerHistory (dataframe): Player history dataframe with kills, deaths and assists categories.
+        kassist (bool, optional): Combine the kill and assist statistics as kassist=kill+0.5*assist. Defaults to True.
+        paint (bool, optional): Use paint stat to plot it as a bar behind the main stats. Defaults to True.
+        kRange (tuple, optional): y-range for the kill+death ratios. Defaults to (0, 50).
+        pRange (tuple, optional): y-range for the paint statistic. Defaults to (0, 2000).
+        rScale (str, optional): Way the circular axis will be scaled. Defaults to 'symlog'.
+        innerOffset (float, optional): Radius of the innermost circle to create a clear area at the centar of the plot. Defaults to 0.75.
+        clockwise (bool, optional): Sorting of the battles starts at 12 o'clock and goes clockwise. Defaults to True.
+        colorsTop (tuple, optional): Color of the line if kills are larger than deaths, and if they are not. Defaults to (cst.CLR_STATS['kill'], cst.CLR_STATS['death']).
+        colorBars (color, optional): Color of the bars assigned to the paint statistic. Defaults to cst.CLR_PAINT.
+        innerText (bool, optional): Add the inner label as the ratio of kills or kassists to deaths. Defaults to True.
+        innerTextFmt (str, optional): Formatting string for the inner label. Defaults to '{:.2f}'.
+        fontSize (int, optional): Font size for the inner label. Defaults to 20.
+        fontColor (str, optional): Font color for the inner label. Defaults to '#00000066'.
+        innerGuides (tuple, optional): Start, stop, increment values for the innermost guides on the radial axis. Defaults to (0, 6, 1).
+        innerGuidesColor (str, optional): Color for the innermost guides. Defaults to "#00000066".
+        outerGuides (tuple, optional): Start stop, increment values for the outermost guides on the radial axis. Defaults to (0, 50, 10).
+        outerGuidesColor (str, optional): Color for the outer guides. Defaults to "#00000088".
+        frameColor (str, optional): Color for the outermost radial frame. Defaults to "#00000011".
+
+    Returns:
+        (fix, ax): Matplotlib's fig and ax objects.
+    """    
+    # Get variables -----------------------------------------------------------
+    (outer, inner) = (
+        np.array(playerHistory['kill']), 
+        np.array(playerHistory['death'])
+    )
+    if kassist:
+        outer = outer + (.5 * np.array(playerHistory['assist']))
+    bar = (np.array(playerHistory['paint']) if paint else None)
+    if innerText:
+        text = np.sum(outer)/np.sum(inner)
+    # Generate plot -----------------------------------------------------------
+    (fig, ax) = plotIris(
+        figAx, outer, inner, barArray=bar,
+        tbRange=kRange, bRange=pRange, rScale=rScale, innerOffset=innerOffset,
+        clockwise=clockwise, colorsTop=colorsTop, colorBars=colorBars,
+        innerText=innerTextFmt.format(text), 
+        fontSize=fontSize, fontColor=fontColor,
+        innerGuides=innerGuides, innerGuidesColor=innerGuidesColor,
+        outerGuides=outerGuides, outerGuidesColor=outerGuidesColor,
+        frameColor=frameColor
+    )
     return (fig, ax)
\ No newline at end of file
